@@ -81,7 +81,7 @@ register_cfunctions(lua_State *lua)
 	lua_register(lua,"get_window_has_name",c_get_window_has_name);
 
 	lua_register(lua,"set_window_position",c_set_window_position);
-	lua_register(lua,"set_window_position2,",c_set_window_position2);
+	lua_register(lua,"set_window_position2",c_set_window_position2);
 	lua_register(lua,"set_window_size",c_set_window_size);
 
 	lua_register(lua,"set_window_geometry",c_set_window_geometry);
@@ -142,6 +142,8 @@ register_cfunctions(lua_State *lua)
 
 	lua_register(lua,"set_viewport",c_set_viewport);
 
+	lua_register(lua,"center",c_center);
+
 #ifdef HAVE_GTK3
 	// wnck_window_get_class_instance_name is only availible on wnck 3 and later
 	lua_register(lua,"get_class_instance_name",c_get_class_instance_name);
