@@ -23,13 +23,14 @@
 /**
  *
  */
-void init_script();
-void done_script();
+lua_State *init_script();
 
-void register_cfunctions();
+void register_cfunctions(lua_State *lua);
+int load_script(lua_State *lua,char *filename);
+
+void run_script(lua_State *lua);
+void done_script(lua_State *lua);
 
-void run_script();
-int load_script(char *filename);
 
 extern gboolean devilspie2_debug;
 extern gboolean devilspie2_emulate;
